#!/bin/sh

# Log file path
LOG_FILE="/usr/src/crontab/asterisk_status.log"

# Function to check if asterisk is responding properly
check_asterisk() {
    output=$(asterisk -rx "core show version" 2>&1)
    exit_code=$?

    # Check if the command was successful and contains version information
    if [ $exit_code -eq 0 ] && echo "$output" | grep -q "Asterisk" && echo "$output" | grep -q "built by"; then
        echo "Asterisk is running properly"
        echo "Version info: $output"
        return 0
    else
        # Log the status with date and time
        date_time=$(date '+%Y-%m-%d %H:%M:%S')
        echo "$date_time Not Running" >> "$LOG_FILE"
        
        echo "Asterisk is not responding properly"
        echo "Error: $output"
        return 1
    fi
}

# Main script
echo "Checking Asterisk status..."

# Check if asterisk is responding
if ! check_asterisk; then
    echo "Attempting to start Asterisk..."

    #Killing all asterisk processes
    killall -9 asterisk
    
    # Try to start asterisk
    asterisk
    
    # Wait for a few seconds to let asterisk initialize
    sleep 5
    
    # Check again if asterisk is now running properly
    if check_asterisk; then
        echo "Successfully started Asterisk"
    else
        echo "Failed to start Asterisk properly. Please check logs for more details"
        exit 1
    fi
fi

exit 0

